import configparser
import os
import time

from common import Feishu, Common, Oss
from common.ffmpeg import FFmpeg
from common.piaoquan_utils import PQ
from common.sql_help import sqlCollect

config = configparser.ConfigParser()
config.read('./config.ini')


class getVideo:
    """
    根据标示+任务标示创建目录
    """
    @classmethod
    def create_folders(cls):
        video_path_url = config['PATHS']['VIDEO_PATH']
        if not os.path.exists(video_path_url):
            os.makedirs(video_path_url)
        return video_path_url


    """
    删除文件
    """
    @classmethod
    def remove_files(cls, video_path_url):
        if os.path.exists(video_path_url) and os.path.isdir(video_path_url):
            for root, dirs, files in os.walk(video_path_url):
                for file in files:
                    file_path = os.path.join(root, file)
                    os.remove(file_path)
                for dir in dirs:
                    dir_path = os.path.join(root, dir)
                    os.rmdir(dir_path)

    """
    获取未改造的视频ID
    """
    @classmethod
    def find_unique_id(cls, data, videos):
        video_ids = [item for item in data if item not in videos]
        data_video_ids = [item for item in video_ids if item is not None and item != '']
        return data_video_ids

    """
    飞书数据处理
    """
    @classmethod
    def video_task(cls):
        video_list = sqlCollect.is_video_id()
        if video_list:
            videos = [item[0] for item in video_list]
            video_path_url = cls.create_folders()  # 创建目录
            for v_id in videos:
                try:
                    video_url, new_title = PQ.get_pw_url(v_id)
                    new_video_path = PQ.download_video(video_url, video_path_url, v_id)  # 下载视频地址
                    if new_video_path == '':
                        Common.logger("log").info(f"{video_url}视频下载失败")
                        cls.remove_files(video_path_url)
                        continue
                    url = FFmpeg.video_duration(new_video_path, video_path_url, v_id)
                    if not os.path.isfile(url):
                        Common.logger("log").info(f"{v_id}下的视频处理失败")
                        cls.remove_files(video_path_url)
                        continue
                    oss_object_key = Oss.stitching_sync_upload_oss(url, v_id)  # 视频发送OSS
                    time.sleep(1)
                    status = oss_object_key.get("status")
                    if status == 200:
                        oss_object_key = oss_object_key.get("oss_object_key")
                        time.sleep(1)
                        sqlCollect.update_task_tencent_material(v_id, oss_object_key)
                        Common.logger("log").info(f"视频ID{v_id} 处理成功 ")
                    else:
                        cls.remove_files(video_path_url)
                        Common.logger("log").info(f"视频ID{v_id} 视频发送OSS失败 ")
                    time.sleep(10)
                except Exception as e:
                    cls.remove_files(video_path_url)
                    Common.logger("log").info(f"处理失败，错误信息{e}")
                    continue








